# dragonking: A python package implementing statistical tests for identification of dragon kings

## Purpose

The dragonking Python package implements published statistical tests and test statistics for identification of dragon kings.

## Installation

## Example use

## Contributions

Please report any bugs, suggestions, or feature requests at the repository's [issues page](https://github.com/dcqin17/dragonking). We welcome any contributions in the form of pull requests from forked versions of this repo.
